#
# -*- coding: utf-8 -*-
'''
$RCSfile: cmfupgrade.py,v $
$Revision: 362 $
$Author: markus $
$Date: 2005-10-12 18:13:45 +0200 (Wed, 12 Oct 2005) $
'''

import sys, os, string, mx.DateTime
from biocase.wrapper.cmf_base import CMFClass
    
class cmfUpgrade(object):
    def __init__(self, cfgObj=None, debug=''):
        if cfgObj is None:
            cfgObj = None
        self.debug=debug
        self.cfgObj = cfgObj
        self.cmfUpgradeDir = os.path.join( cfgObj.rawCmfTemplateLocator, 'upgrades')
        # read index dictionary for upgrade files
        class Index( object ):
            pass
        indexObj = Index()
        execfile( os.path.join(self.cmfUpgradeDir,'index.py'), globals(), indexObj.__dict__ )
        self.indexDict     = indexObj.index
        self.debug + "Full available upgrade ditcionary:"
        self.debug + unicode(self.indexDict)
        
        
    def listPossibleUpgrades(self, sourceCmfNS):
        '''Return a list of raw cmf filenames without suffix suitable for upgrading a given cmf.'''
        if not self.indexDict.has_key(sourceCmfNS):
            return []
        return [ t[1][:-4] for t in self.indexDict[sourceCmfNS].values() ]
        
    def listPossibleUpgradeTuples(self, sourceCmfNS):
        '''Return a dict (key=namespace) of tuples (rawCmfFileName, upgradeFileName) 
        for all available upgrades of a given cmf namespace.'''
        if self.indexDict.has_key(sourceCmfNS):
            self.debug + "List possible upgrades for ns=%s: %s" % (sourceCmfNS, unicode( self.indexDict[sourceCmfNS].keys() ))
            return self.indexDict[sourceCmfNS]
        elif self.indexDict.has_key(sourceCmfNS.lower() ):
            self.debug + "List possible upgrades for ns=%s: %s" % (sourceCmfNS.lower(), unicode( self.indexDict[sourceCmfNS.lower()].keys() ))
            return self.indexDict[sourceCmfNS.lower()]
        else:
            self.debug + "No possible upgrades for ns=%s"%sourceCmfNS
            return {}

    def getUpgradedCmfObj(self, cmfFileName, targetNamespace):
        '''Return a cmf object based on the upgraded namespace and the appropiate upgrade file.
        All existing mappings that couldnt be transfered are returned as a list in the second parameter.'''
        if os.path.isfile(cmfFileName):
            # read existing CMF
            oldCmf = CMFClass()
            oldCmf.loadCMFdata( cmfFileName)
            if self.indexDict.has_key(oldCmf.getRootNamespace()) or self.indexDict.has_key(oldCmf.getRootNamespace().lower()):
                # upgradeTuple
                if self.indexDict[oldCmf.getRootNamespace()].has_key(targetNamespace):
                    upgradeTuple = self.indexDict[oldCmf.getRootNamespace()][targetNamespace]
                elif self.indexDict[oldCmf.getRootNamespace().lower()].has_key(targetNamespace):
                    upgradeTuple = self.indexDict[oldCmf.getRootNamespace()][targetNamespace]
                else:
                    return None, [], (None,None)
            else:
                return None, [], (None,None)
        else:
            return None, [], (None,None)
        
        self.debug + "UPGRADING CMF %s to NS %s ..." % (oldCmf.getRootNamespace(), targetNamespace)
        # new target cmf object
        newCmf = CMFClass()
        rawCmfPath      = os.path.join( self.cfgObj.rawCmfTemplateLocator, upgradeTuple[0] )
        newCmf.loadCMFdata( rawCmfPath )
        # transfer non mapping properties
        newCmf.name           = oldCmf.name
        newCmf.generated_by   = "Configtool lib $Revision: 362 $"
        newCmf.generated_when = str(mx.DateTime.now())
        newCmf.omitNS         = oldCmf.omitNS
        newCmf.tableTreeObj.rootTableAlias = oldCmf.tableTreeObj.rootTableAlias
        # transfer mappings
        # read upgrade file...
        upgradeFilePath = os.path.join( self.cmfUpgradeDir, upgradeTuple[1] )
        upgradeDict = {}
        for line in file(upgradeFilePath).readlines():
            sourcePath, targetPath = line.split( chr(9) )
            sourcePath = sourcePath.strip()
            targetPath = targetPath.strip()
            if upgradeDict.has_key(sourcePath):
                upgradeDict[sourcePath].append( targetPath )
            else:
                upgradeDict[sourcePath] = [targetPath]
        # get dict of mappings with key=concept path, value=list of mapping objects
        mappings = oldCmf.removeMappings()
        newMappings = {}
        missingConcepts = {}
        for path, map in mappings.items():
            if upgradeDict.has_key(path):
                self.debug + "  Move mappings from %s to %s" %(path, unicode(upgradeDict[path]) )
                for targetPath in upgradeDict[path]:
                    if not newMappings.has_key(targetPath):
                        newMappings[targetPath] = []
                    newMappings[targetPath] += map[:]
            else:
                missingConcepts[path] = map
        # update newCmf
        newCmf.setMappings( newMappings )
        # log missing concepts
        self.debug + "  The following missing concepts couldnt be included in the upgraded CMF:"
        for path, map in missingConcepts.items():
            self.debug + "Concept %s : %s" % (path, unicode(map) )
        # return cmf and missing concepts mapping dict
        return newCmf, missingConcepts, upgradeTuple
        
        
        