#
# -*- coding: utf-8 -*-

'''General things all querytool scripts need.
It also adjusts the sys path via biocase.adjustpath.py .
This module should be executed via execfile('ABS PATH TO HERE'). 
'''

############################################################################################################
#
#   IMPORTS
#
#===========================================================================================================

import cgitb; cgitb.enable()
import cgi, os, sys, string, md5, time, random
from stat import ST_MTIME
from types import *

import biocase.configuration
from biocase.wrapper.errorclasses import *
from biocase.configtool        import __version__
from biocase.tools.debugging   import DebugClass
from biocase.datasources       import Datasource
from biocase.tools.htmltools   import ankerClass, escapeHtml, getDropDownHtml, getDropDownOptionHtml
from biocase.tools.templating  import PageMacro, genOptionList
from biocase.tools.various_functions import getEncodingList, getDBMSList



############################################################################################################
#
#   GENERAL FUNCTIONS
#
#===========================================================================================================
def printOverHTTP(templ, debug=None, diagnostics=None):
    print cfg.http_header
    if debug.display > 0:
        if diagnostics is not None:
            templ['diagnostics'] = '''<p class="label">Diagnostics:</p>
            <pre>%s</pre>''' %escapeHtml( string.join( diagnostics, '\n * ' ) )
        templ['debug'] = '''<p class="label">Debugging:</p>
        <pre>%s</pre>''' %str(debug)
    print str(templ)

# ------------------------------------------------------------------------------------
def authenticate(MD5passwd, clearPasswd, dsa=None):
    '''Check MD5 encrypted password with temporary DSA .password file.
    Removes file if older than 30 minutes.'''
    global cfg
    passwdFilename = '.password'
    # check file
    if dsa is not None:
        passwdFile = os.path.join(cfg.datasourcesLocator, dsa, passwdFilename)
    else:
        # system admin part
        passwdFile = os.path.join(cfg.datasourcesLocator, passwdFilename)
    # check if file is not older than 30 minutes
    if MD5passwd == '' or MD5passwd is None or not os.path.isfile(passwdFile) or os.stat(passwdFile)[ST_MTIME] + 1800 < int(time.time()):
        return authenticateInitially(clearPasswd, passwdFile)
    # compare md5 passwords from file and parameter
    content = file(passwdFile).read()
    if content == MD5passwd:
        # update filedate to now
        file(passwdFile, 'w').write(content)
        return MD5passwd
    return authenticateInitially(clearPasswd, passwdFile)
    
# ------------------------------------------------------------------------------------
def authenticateInitially(clearPasswd, passwdFile):
    '''Compare clear password with DSA or system config files.
    systemAdmin password allows to edit anything.
    datasource specific passwords are stored in the configtool prefs of the datasource
    and allow to edit that dsa only.
    If system wide authentication is required, leave the dsa parameter None.'''
    if clearPasswd == '' or clearPasswd is None:
        return False
    elif clearPasswd == cfg.configtool.adminPassword:
        return createAuthenPasswordFile(clearPasswd, passwdFile)
    # check alternatively for dsa specific password
    elif dsa is not None:
        dsaObj = Datasource(name=dsa)
        psfObj = dsaObj.getPSFObj()
        if clearPasswd == psfObj.adminpassword:
            return createAuthenPasswordFile(clearPasswd, passwdFile)
    return False

# ------------------------------------------------------------------------------------
def createAuthenPasswordFile(clearPasswd, passwdFile):
    #MD5Passwd = md5.new("%s-%f" %(clearPasswd, time.time()) ).digest()
    MD5Passwd = str( random.randint(100000000000000,999999999999999) )
    debug + "MD5 password file created: %s"%MD5Passwd
    file(passwdFile, 'w').write(MD5Passwd)
    return MD5Passwd

# ------------------------------------------------------------------------------------
def authenticationForm(script='main.py', dsa=None):
    global templateDir, debug, diagnostics
    tmpl = PageMacro('Content', PageMacro.DELMODE)
    tmpl.load('Content', os.path.join(templateDir, '_password.html'))
    if dsa is not None:
        tmpl['dsa'] = dsa
    tmpl['script'] = script
    # print HTML !
    printOverHTTP( tmpl, debug, diagnostics )    
    # stop script
    sys.exit()
    
# ------------------------------------------------------------------------------------
def readTmpCmFile(cmfObj, cmFile, psfObj):
    global cfg, debug
    cmFilePickle = cmFile + cfg.configtool.tmpCmfPickleSuffix
    if os.path.isfile( cmFilePickle ):
        debug + "Read existing pickled tmp file %s"%(cmFilePickle)
        isGood = cmfObj.__unpickle__(filename=cmFilePickle)
        if not isGood:
            debug + "Failed to read pickled file. Read original CMF xml-file."
            readOriginalCmFile(cmfObj, cmFile=cmFile, psfObj=psfObj)
    else:
        readOriginalCmFile(cmfObj, cmFile=cmFile, psfObj=psfObj)
    debug + "altRootTableAliasSPICE = %s" % unicode(cmfObj.altRootTableAliasSPICE)
        

# ------------------------------------------------------------------------------------
def readOriginalCmFile(cmfObj, psfObj, cmFile=None):
    global cfg, debug
    debug + "Read original CMF xml-file %s"%(cmFile)
    try:
        cmfObj.loadCMFdata( filename=cmFile, psfObj=psfObj, pickle=1 )
    except TableConfigError:
        debug + "CMF file %s and the PSF dont match. Table config errors."%(cmFile)
    
    
    
############################################################################################################
#
#   MAIN
#
#===========================================================================================================


# get global project configurations
cfg = biocase.configuration.Cfg('configtool')
# dirs used with the configtool
configDir   = os.path.join(cfg.configurationLocator, 'configtool') # configtool config dir
templateDir = os.path.join(cfg.wwwLocator, 'configtool') 
# debugging
debug = DebugClass()
diagnostics = None


#
# ANALYZE CGI ENVIRONMENT
#
form = cgi.FieldStorage()
debug + "CGI FORM VALUES: %s"%str(form.keys())

# debugging
if form.has_key('debug'):
    debug.display = True
else:
    debug.display = cfg.configtool.debug

# passwords
clearPasswd = form.getfirst('passwd', None)
debug + "Passwd clear=%s"%str(clearPasswd)
MD5Passwd = form.getfirst('id', None)
debug + "Passwd MD5=%s"%str(MD5Passwd)

# dsa
dsa = form.getfirst('dsa',None)
if dsa is not None:
    dsaObj = Datasource(name=dsa, cfg=cfg, debug=debug)
else:
    dsaObj = None
debug + "DSA=%s"%str(dsa)
    
# schema
schema = form.getfirst('schema', None)
debug + "Schema=%s"%str(schema)
    
# action
action = form.getfirst('action', form.getfirst('action_override', None))
if action is not None:
    action = action.lower()
debug + "Action=%s"%str(action)
