#
# -*- coding: utf-8 -*-
'''
$RCSfile: configuration.py,v $
$Revision: 3 $
$Author: markus $
$Date: 2005-07-01 17:15:59 +0200 (Fri, 01 Jul 2005) $
'''

############################################################################################################
#
#   IMPORTS AND CONSTANTS
#
#===========================================================================================================
import inspect as           _i
import os.path as           _p
import os as                _os
from cgi import escape as   _esc
from types import DictType


############################################################################################################
#
#   CONFIGURATION SECTION CLASS
#
#===========================================================================================================
class ConfigurationSection( object ):

    #-------------------------------------------------------------------------------------------------------
    pass


############################################################################################################
#
#   GLOBAL CONFIGURATION BASE CLASS. might be replaced by another class when using getCfg()
#
#===========================================================================================================
class Cfg( object ):

    #-------------------------------------------------------------------------------------------------------
    _configurationSectionClass  = ConfigurationSection
    #-------------------------------------------------------------------------------------------------------
    libbiocaseLocator           = _p.abspath( _p.dirname( _i.getfile( lambda:None ) ) )
    libLocator                  = _p.abspath( _p.join( libbiocaseLocator,   _os.pardir          ) )
    homeLocator                 = _p.abspath( _p.join( libLocator,          _os.pardir          ) )
    wwwLocator                  = _p.join( homeLocator,             'www'                       )
    xslLocator                  = _p.join( homeLocator,             'www','resources','xsl'     )
    configurationLocator        = _p.join( homeLocator,             'configuration'             )
    datasourcesLocator          = _p.join( configurationLocator,    'datasources'               )
    persistenceLocator          = _p.join( configurationLocator,    'persistence'               )
    rawCmfTemplateLocator       = _p.join( configurationLocator,    'templates','cmf'           )
    prefilledTemplateLocator    = _p.join( configurationLocator,    'templates','prefilled'     )
    logLocator                  = _p.join( homeLocator,             'log'                       )

    #-------------------------------------------------------------------------------------------------------
    def _dictAsTable( self, d, indent=0 ):
        R = [ ]
        names = d.keys()
        names.sort()
        for name in names:
            value = d[ name ]
            if type(value) == DictType:
                value = '\n' + self._dictAsTable(d[ name ], indent+1)
            indentString = '  '*indent
            R.append( '%s%s:\t%s' % ( indentString, name, value, ) )
        R = '\n'.join( R )
        return R

    #-------------------------------------------------------------------------------------------------------
    def _dictAsHtmlTable( self, d ):
        R = [ '<table border="1" cellspacing="0" cellpadding="1" style="font-size:85%">' ]
        names = d.keys()
        names.sort()
        for name in names:
            value = d[ name ]
            if type(value) == DictType:
                value = '\n' + self._dictAsHtmlTable(d[ name ])
            else:
                value = _esc( unicode(d[ name ]) )
            name_ = _esc( name )
            R.append( '<tr><td><b>%s</b></td><td>%s</td></tr>' % ( name_, value, ) )
        R.append( '</table>' )
        R = '\n'.join( R )
        return R

    #-------------------------------------------------------------------------------------------------------
    def _environmentAsTable( self, html = False ):
        if html:
            return self._dictAsHtmlTable( _os.environ )
        else:
            return self._dictAsTable( _os.environ )

    #-------------------------------------------------------------------------------------------------------
    def _getRecursiveDict( self, obj=None ):
        if obj == None:
            obj = self
        R = {}
        for name in dir( obj ):
            if name.startswith( '_' ): continue
            if isinstance(getattr( obj, name ), ConfigurationSection):
                R[ name ] = self._getRecursiveDict( obj=getattr( obj, name ) )
            else:
                R[ name ] = getattr( obj, name )
        return R
        
    #-------------------------------------------------------------------------------------------------------
    def _asTable( self, html = False, showEnvironment = False ):
        R = self._getRecursiveDict()
        if html:
            return self._dictAsHtmlTable( R )
        else:
            return self._dictAsTable( R )

    #-------------------------------------------------------------------------------------------------------
    def __repr__( self ):
        return self._asTable()

    #-------------------------------------------------------------------------------------------------------
    def __init__( self, *includes ):
        #---------------------------------------------------------------------------------------------------
        globalConfigurationLocator  = _p.join( self.configurationLocator, '.configuration' )
        self._postprocessingMethods = []
        #---------------------------------------------------------------------------------------------------
        execfile( globalConfigurationLocator, globals(), self.__dict__ )
        postprocessingMethodname = 'postprocess'
        postprocessingMethod = getattr( self, postprocessingMethodname, None )
        if postprocessingMethod is not None:
            self._postprocessingMethods.append( postprocessingMethod )
        #---------------------------------------------------------------------------------------------------
        for include in includes:
            sectionConfigurationLocator = _p.join( self.configurationLocator, include, '.configuration' )
            section = self.__class__._configurationSectionClass()
            execfile( sectionConfigurationLocator, globals(), section.__dict__ )
            setattr( self, include, section )
            postprocessingMethodname = 'postprocess_%s' % ( include, )
            postprocessingMethod = getattr( self, postprocessingMethodname, None )
            if postprocessingMethod is not None:
                self._postprocessingMethods.append( postprocessingMethod )
                #postprocessingMethod()

    #-------------------------------------------------------------------------------------------------------
    def postprocess( self ):
        """General postprocessing method. The method is registered in ``~._postprocessingMethods`` and
        executed by ``fundamentals.py`` when objects like ``g.cfg`` are available."""
        _inter = g.configtool.utilities.kpyInterpol.inter
        additionalGraphsourcesByPrefix = g.cfg.additionalGraphsourcesByPrefix
        #print '%%%%%%%%%%%%%%%%%%%%%', dir( g.cfg.configtool )
        for prefix, locatortemplate in additionalGraphsourcesByPrefix.iteritems():
            additionalGraphsourcesByPrefix[ prefix ] = _inter( locatortemplate )

    #-------------------------------------------------------------------------------------------------------
    def postprocess_configtool( self ):
        """Example for a specialized postprocessing method; does nothing."""
        _inter = g.configtool.utilities.kpyInterpol.inter
        g.cfg.configtool.assessmentsHomelocator = _inter( g.cfg.configtool.assessmentsHomelocator )

############################################################################################################
#
#
#
#===========================================================================================================
if __name__ == '__main__':

    import sys
    sys.setrecursionlimit( 50 )

    cfg = Cfg('pywrapper')
    print cfg
    print
    print cfg._asTable(html=True, showEnvironment=False)




