#
# -*- coding: utf-8 -*-

''' TBD '''


############################################################################################################
#
#   IMPORTS
#
#===========================================================================================================
from biocase.querytool import __version__
from mx.DateTime import now




############################################################################################################
#
#   CLASSES
#
#===========================================================================================================
class QueryGenerator:
    '''A class to generate biocase protocol xml strings.'''
    
    NS_DiGIR   = "http://digir.net/schema/protocol/2003/1.0"
    NS_BioCASe = "http://www.biocase.org/schemas/protocol/1.3"
    NS_TAPIR   = ''
    
    # ------------------------------------------------------------------------------------
    def __init__(self, protocolNS=None):
        if protocolNS is None:
            protocolNS = QueryGenerator.NS_BioCASe
        self._type = protocolNS
        
    # ------------------------------------------------------------------------------------
    def getCapabilitiesProtocol(self):
        return u'''<?xml version="1.0" encoding="UTF-8"?>
    <!-- XML generated by biocase.querytool.querygenerator. -->
    <request 
        xmlns="%s" 
        xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" 
        xsi:schemaLocation="%s http://www.bgbm.org/biodivinf/Schema/protocol_1_3.xsd">
        <header>
            <version software="querytool">%s</version>
            <sendTime>%s</sendTime>
            <source/>
            <destination/>
            <type>capabilities</type>
        </header>
    </request>''' %(QueryGenerator.NS_BioCASe, QueryGenerator.NS_BioCASe, __version__, str( now() ))
    
    # ------------------------------------------------------------------------------------
    def getScanProtocol(self, concept, NS="http://www.tdwg.org/schemas/abcd/1.2", filterObj=None):
        if filterObj is not None:
            filter = "\n<filter>%s\n</filter>\n"%filterObj.getProtocolXML()
        else:
            filter = ''
        return u'''<?xml version="1.0" encoding="UTF-8"?>
    <request 
        xmlns="%s" 
        xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" 
        xsi:schemaLocation="%s http://www.bgbm.org/biodivinf/schema/protocol.xsd">
        <header>
            <version software="querytool">%s</version>
        <sendTime>%s</sendTime>
            <type>scan</type>
        </header>
        <scan>
            <requestFormat>%s</requestFormat>
            <concept>%s</concept>
            %s
        </scan>
    </request>''' %(self._type, self._type, __version__, str(now()), NS, concept, filter)
    

    # ------------------------------------------------------------------------------------
    def getSearchProtocol(self, reqNS="http://www.tdwg.org/schemas/abcd/1.2", respNS="http://www.tdwg.org/schemas/abcd/1.2", start=0, limit=100, count=False, filterObj=None, destination=None):
        '''Parameter destination should be the access point for the service.
        In the case of DiGIR resources should be provided in the form of RESOURCE@ACCESSPOINT as the destination string.'''
        # if digir destination parse resource of form RESOURCE@ACCESSPOINT
        if destination is not None:
            if destination.count("@") == 1:
                digirResource, destination = destination.split("@")
            else:
                digirResource = ''
        else:
            digirResource = ''
            destination   = ''
        # prepare filter string
        if filterObj is not None:
            filter = filterObj.getProtocolXML()
        else:
            filter = ''
        if self._type == QueryGenerator.NS_BioCASe:
            return u'''<?xml version="1.0" encoding="UTF-8"?>
        <!--XML generated by BioCASE query tool for a single database, written by Markus Doering and Javier de la Torre, Botanic Garden and Botanical Museum, Berlin.-->
        <request 
            xmlns="%s" 
            xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" 
            xsi:schemaLocation="%s http://www.bgbm.org/biodivinf/Schema/protocol_1_3.xsd">
            <header>
                <version software="querytool">%s</version>
                <sendTime>%s</sendTime>
                <source/>
                <destination>%s</destination>
                <type>search</type>
            </header>
            <search>
                <requestFormat>%s</requestFormat>
                <responseFormat start="%i" limit="%i">%s</responseFormat>
                <filter>
                  %s
                </filter>
                <count>%s</count>
            </search>
        </request>
        ''' %(self._type, self._type, __version__, str(now()), destination, reqNS, start, limit, respNS, filter, str(count))
    
        elif self._type == QueryGenerator.NS_DiGIR:
            return u'''<?xml version="1.0" encoding="UTF-8"?>
<request 
    xmlns="%s" 
    xmlns:xsd="http://www.w3.org/2001/XMLSchema" 
    xmlns:darwin="%s 
    xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" 
    xsi:schemaLocation="%s 
      http://digir.sourceforge.net/schema/protocol/2003/1.0/digir.xsd 
      %s 
      http://digir.sourceforge.net/schema/conceptual/darwin/2003/1.0/darwin2.xsd">
    <header>
      <version>1.0</version>
      <sendTime>%s</sendTime>
      <source/>
      <destination resource="%s">%s</destination>
      <type>search</type>
    </header>
    <search>
      <filter>
          %s
      </filter>

      <records limit="%i" start=%i">
        <structure>
          <xsd:element name="record">
            <xsd:complexType>
              <xsd:sequence>
                <xsd:element ref="darwin:InstitutionCode"/>
                <xsd:element ref="darwin:CollectionCode"/>
                <xsd:element ref="darwin:CatalogNumber"/>
                <xsd:element ref="darwin:ScientificName"/>

                <xsd:element name="coordinates">
                  <xsd:complexType>
                     <xsd:sequence>
                      <xsd:element ref="darwin:Latitude"/>
                      <xsd:element ref="darwin:Longitude"/>
                     </xsd:sequence>
                  </xsd:complexType>
                </xsd:element>
              </xsd:sequence>

            </xsd:complexType>
          </xsd:element>
        </structure>
      </records>
      <count>false</count>
    </search>        
    </request>''' %(self._type, respNS, self._type, respNS, str(now()), digirResource, destination, filter, start, limit)
    
    